@@ -182,10 +182,8 @@ $GLOBALS['strPasswordRepeat'] = "סיסמא שוב";
 $GLOBALS['strAccessDenied'] = "גישה לא מאושרת";
 $GLOBALS['strUsernameOrPasswordWrong'] = "שם משתמש או סיסמא שגויים.";
 $GLOBALS['strPasswordWrong'] = "הסיסמא לא נכונה.";
-$GLOBALS['strNotAdmin'] = "איך לך הרשאה מספקת";
 $GLOBALS['strDuplicateClientName'] = "שם המשתמש שבחרת כבר קיים, נא לבחור שם אחר.";
 $GLOBALS['strInvalidPassword'] = "סיסמא פסולה";
-$GLOBALS['strInvalidEmail'] = "כתובת דוא''ל לא חוקית.";
 $GLOBALS['strNotSamePasswords'] = "סיסמאות אינן תואמות";
 $GLOBALS['strRepeatPassword'] = "חזור על הסיסמא";
 $GLOBALS['strDeadLink'] = "הקישור שלך אינו חוקי.";
@@ -987,9 +985,7 @@ $GLOBALS['strTrackerTypeCustom'] = "Custom JS code";
 $GLOBALS['strVariableCode'] = "Javascript tracking code";
 
 // Password recovery
-$GLOBALS['strForgotPassword'] = "שכחת סיסמא?";
 $GLOBALS['strEmailRequired'] = "דוא''ל הוא שדה חובה";
-$GLOBALS['strPwdRecEnterEmail'] = "Enter your email address below";
 $GLOBALS['strPwdRecEnterPassword'] = "Enter your new password below";
 $GLOBALS['strProceed'] = "Proceed >";
 
