@@ -191,10 +191,10 @@ $GLOBALS['strPasswordRepeat'] = "Herhaal het wachtwoord";
 $GLOBALS['strAccessDenied'] = "Toegang geweigerd";
 $GLOBALS['strUsernameOrPasswordWrong'] = "De gebruikersnaam en/of het wachtwoord zijn niet juist. Probeer het alstublieft opnieuw.";
 $GLOBALS['strPasswordWrong'] = "Het wachtwoord is niet correct";
-$GLOBALS['strNotAdmin'] = "Uw account beschikt niet over de vereiste toestemming om deze functie te gebruiken, U kunt inloggen op een andere account om dit te gebruiken.";
+$GLOBALS['strNotAdmin'] = "Uw gebruiker beschikt niet over de vereiste toestemming om deze functie te gebruiken, u kunt inloggen met een andere gebruikersnaam om dit te gebruiken.";
 $GLOBALS['strDuplicateClientName'] = "De gebruikersnaam die u wenst is al in gebruik, gelieve een andere gebruikersnaam te gebruiken.";
 $GLOBALS['strInvalidPassword'] = "Het nieuwe wachtwoord is niet geldig, voer een ander wachtwoord in.";
-$GLOBALS['strInvalidEmail'] = "Het e-mail adres is niet correct opgemaakt, voer svp een juist e-mailadres in.";
+$GLOBALS['strInvalidEmail'] = "Het e-mailadres is niet correct geformatteerd. Voer s.v.p. een correct geformatteerd e-mailadres in.";
 $GLOBALS['strNotSamePasswords'] = "De twee wachtwoorden die u ingevoerd heeft zijn niet hetzelfde";
 $GLOBALS['strRepeatPassword'] = "Herhaal het wachtwoord";
 $GLOBALS['strDeadLink'] = "Deze link is ongeldig";
@@ -1043,13 +1043,13 @@ $GLOBALS['strTrackerTypeCustom'] = "Aangepaste JS code";
 $GLOBALS['strVariableCode'] = "JavaScript tracking-code";
 
 // Password recovery
-$GLOBALS['strForgotPassword'] = "Wachtwoord vergeten?";
+$GLOBALS['strForgotPassword'] = "Vraag een wachtwoord reset e-mail aan";
 $GLOBALS['strPasswordRecovery'] = "Wachtwoord opnieuw instellen";
 $GLOBALS['strWelcomePage'] = "Welkom nieuwe gebruiker!";
 $GLOBALS['strWelcomePageText'] = "<b>Welkom bij {$PRODUCT_NAME}.</b><br>Als nieuwe gebruiker, begin met het instellen van uw eerste wachtwoord. Zorg ervoor dat u een veilig en uniek wachtwoord kiest.";
 $GLOBALS['strEmailRequired'] = "E-mail is een verplicht veld";
 $GLOBALS['strPwdRecWrongExpired'] = "Onjuiste of verlopen link om het wachtwoord te resetten, vraag een nieuwe aan";
-$GLOBALS['strPwdRecEnterEmail'] = "Voer hieronder uw e-mail adres in";
+$GLOBALS['strPwdRecEnterEmail'] = "Voer hieronder uw e-mailadres in om een wachtwoord reset e-mail te ontvangen";
 $GLOBALS['strPwdRecEnterPassword'] = "Voer uw nieuwe wachtwoord hieronder in";
 $GLOBALS['strProceed'] = "Doorgaan >";
 $GLOBALS['strNotifyPageMessage'] = "Er is een e-mail naar u gestuurd, met daarin een link die u in staat stelt
